@@ -401,9 +401,11 @@ def get_response(session, operation, http_response):
         streaming_response.parse(http_response.headers, http_response.raw)
         return (http_response, streaming_response.get_value())
     body = http_response.content
+    logger.debug(
+        "Response Headers:\n%s",
+        '\n'.join("%s: %s" % (k, v) for k, v in http_response.headers.items()))
     logger.debug("Response Body:\n%s", body)
-    if content_type in ('application/x-amz-json-1.0',
-                        'application/x-amz-json-1.1', 'application/json'):
+    if operation.service.type == 'json':
         json_response = JSONResponse(session, operation)
         if body:
             json_response.parse(body, encoding)
